@@ -3,7 +3,8 @@ from .lambda_events import (
     IncomingMessageCallbackEvent, QualityTestCallbackEvent, SmartTaggingCallbackEvent,
     QualityTestInteractionCallbackEvent, IncomingMessageEvent, QualityTestEvent,
     AllQualityTestEvent, FollowUpEvent, SmartTaggingEvent, QualityTestEventData, AllQualityTestEventData,ChatData,
-    ComparisonAnalysisCallbackMetadata, InteractionCallbackMetadata, SmartTaggingCallbackMetadata
+    ComparisonAnalysisCallbackMetadata, InteractionCallbackMetadata, SmartTaggingCallbackMetadata,
+    SmartTaggingPromptEvent
 )
 from .lambda_invokation_types import InvokationType, LambdaAiEvent
 from .openai_payloads import OpenaiPayload, N8nPayload
\ No newline at end of file
