@@ -9,6 +9,10 @@ class TemplateSource(SourceBase):
     source_checker: SourceCheckerType = Field(default=SourceCheckerType.TEMPLATE)
     template_name: str
 
+    @property
+    def default_category(self) -> str:
+        return "Templates"
+
     @property
     def type(self) -> SourceType:
         return SourceType.TEMPLATE_SOURCE
