@@ -10,6 +10,7 @@ from .utms.utm_query_params import QueryUTMParams
 
 class UTMSource(SourceBase):
     utm_campaign: str = Field(default="")
+    url: str = Field(description="The URL of the UTM source")
     source_checker: SourceCheckerType = Field(default=SourceCheckerType.CHATTY_PIXEL)
     meta_ad_id: Optional[str] = Field(default=None)
     google_ad_id: Optional[str] = Field(default=None)
@@ -35,7 +36,11 @@ class UTMSource(SourceBase):
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, UTMSource):
             return False
-        return self.utm_campaign == other.utm_campaign
+        return self.utm_campaign == other.utm_campaign and self.utm_campaign != ""
 
     def __hash__(self) -> int:
-        return hash(self.utm_campaign)
\ No newline at end of file
+        return hash(self.utm_campaign)
+
+    @property
+    def has_utm_campaign(self) -> bool:
+        return self.utm_campaign != ""
\ No newline at end of file
