@@ -109,4 +109,8 @@ class QueryUTMParams(BaseModel):
             if getattr(self, param)
         ]
 
-        return utm + "&".join(params)
\ No newline at end of file
+        return utm + "&".join(params)
+
+    @property
+    def has_utm_campaign(self) -> bool:
+        return self.utm_campaign != ""
\ No newline at end of file
