@@ -56,11 +56,31 @@ class AiAgentComponent(CompanyAssetModel):
     is_essential: Optional[bool] = Field(default=False, description="Whether the component is essential for the ai agent to work")
     icon: Optional[str] = Field(default=None, description="The icon of the component")
     is_draft: bool = Field(default=False, description="Whether the component is a draft")
+    ai_agent_id: Optional[StrObjectId] = Field(default=None, description="The ai agent that is related to the component")
 
+    @property
     def has_conditional_filters(self) -> bool:
         """Check if the model has assets restrictions"""
         return len(self.filter_criteria) > 0
 
+    @property
     def is_always_on(self) -> bool:
         """Check if the model is always on"""
-        return len(self.filter_criteria) == 0
\ No newline at end of file
+        return len(self.filter_criteria) == 0
+
+    @property
+    def is_global_component(self) -> bool:
+        """Check if the component is global"""
+        return self.ai_agent_id is None
+
+    @property
+    def is_only_for_one_ai_agent(self) -> bool:
+        """Check if the component is only for one ai agent"""
+        return self.ai_agent_id is not None
+
+    @property
+    def ai_agent_id_value(self) -> StrObjectId:
+        """Set the ai agent id for the component"""
+        if not self.ai_agent_id:
+            raise ValueError("The component is not only for one ai agent")
+        return self.ai_agent_id
\ No newline at end of file
