@@ -17,6 +17,8 @@ from ..company.assets.chat_assets import ChattyAIAgentAssignedToChat
 from ..messages.chatty_messages.base.message_draft import MessageDraft
 from ..utils.custom_exceptions.custom_exceptions import MissingAIAgentForSmartFollowUp
 from .time_left import TimeLeft
+from ..company.conversation_topic import TopicTimelineEntry
+from ..company.form_field import CollectedData
 import json
 import logging
 logger = logging.getLogger(__name__)
@@ -44,6 +46,7 @@ class Chat(CompanyAssetModel):
     flow_states: List[FlowStateAssignedToChat] = Field(default_factory=list)
     chatty_ai_agent: Optional[ChattyAIAgentAssignedToChat] = Field(default=None, description="The id of the chatty ai agent that might or might not be assigned to the chat")
     suggested_messages: List[MessageDraft] = Field(default_factory=list)
+    topics_timeline: List[TopicTimelineEntry] = Field(default_factory=list, description="Timeline of conversation topics throughout the conversation")
     model_config = ConfigDict(extra="ignore")
 
     @property
@@ -188,6 +191,18 @@ class Chat(CompanyAssetModel):
         """Get the real messages in the chat"""
         return [message for message in self.messages if message.type != MessageType.CENTRAL]
 
+    @property
+    def active_topics(self) -> List[str]:
+        """
+        Get currently active conversation topics (last timeline entry).
+
+        Returns:
+            List of topic names currently active
+        """
+        if not self.topics_timeline:
+            return []
+        return self.topics_timeline[-1].topics
+
     @property
     def last_message_timestamp(self) -> Optional[datetime]:
         """Get the timestamp of the last message in the chat"""
