@@ -47,8 +47,9 @@ class FlowStateAssignedToChat(AssignedAssetToChat):
     execution_attempts: int = Field(default=0)
 
     model_config = ConfigDict(
-        populate_by_name=True,
         arbitrary_types_allowed=True,
+        validate_by_name=True,
+        validate_by_alias=True
     )
 
     def model_dump_json(self, *args, **kwargs) -> Dict[str, Any]:
