@@ -31,6 +31,8 @@ class SmartFollowUpDecision(BaseModel):
         return self.next_call_time
 
     def add_follow_up_strategy_info_to_chain_of_thought(self, follow_up_strategy_info: str):
+        if self.chain_of_thought.chain_of_thought is None:
+            self.chain_of_thought.chain_of_thought = ""
         self.chain_of_thought.chain_of_thought += f"\n\n La decisión fue: {self.action} \n{follow_up_strategy_info}"
 
     @model_validator(mode="after")
@@ -102,4 +104,4 @@ class IncomingMessageAIDecision(BaseModel):
     def set_chain_of_thought_id(self, chain_of_thought_id: str):
         if self.messages:
             for message in self.messages:
-                message.context_value.chain_of_thought_id = chain_of_thought_id
\ No newline at end of file
+                message.context_value.chain_of_thought_id = chain_of_thought_id
