@@ -1,4 +1,4 @@
-from pydantic import Field, BaseModel
+from pydantic import ConfigDict, Field, BaseModel
 from typing import Optional
 from ....base_models import CompanyAssetModel
 from ....utils.types.identifier import StrObjectId
@@ -13,6 +13,7 @@ class ChainOfThoughtInChatTrigger(StrEnum):
     FOLLOW_UP = "follow_up"
     MANUAL_TRIGGER = "manual_trigger"
     AUTOMATIC_TAGGING = "automatic_tagging"
+    RETRY_CALL = "retry_call"
 
 class ChainOfThoughtInChatStatus(StrEnum):
     """Status for the chain of thought in chat"""
@@ -30,6 +31,12 @@ class ChainOfThoughtInChatRequest(BaseModel):
     chain_of_thought : Optional[str] = Field(default=None, description="The chain of thought")
     name: str = Field(description="A title for the chain of thought", alias="title")
 
+    model_config = ConfigDict(
+        validate_by_name=True,
+        validate_by_alias=True,
+        arbitrary_types_allowed=True
+                )
+
     @classmethod
     def example(cls) -> dict:
         return {
