@@ -1,10 +1,12 @@
 from __future__ import annotations
 from zoneinfo import ZoneInfo
 from letschatty.models.base_models.ai_agent_component import AiAgentComponentType
+from letschatty.models.company.assets.ai_agents_v2.knowleadge_base_components import KnowleadgeBaseComponent
 from pydantic import BaseModel, Field
 from datetime import datetime
 from typing import List, Any, ClassVar, Optional
 from enum import StrEnum
+from typing import Dict
 from letschatty.models.base_models.ai_agent_component import AiAgentComponent
 from letschatty.models.utils.types.identifier import StrObjectId
 from letschatty.models.company.assets.ai_agents_v2.chat_example import ChatExample, ExampleElement
@@ -32,6 +34,8 @@ class ChatExampleTestCase(AiAgentComponent):
     ai_agent_id: StrObjectId = Field(..., description="The id of the ai agent")
     comments: Optional[str] = Field(default=None, description="The comments of the example test")
     last_processed_interaction_index: int = Field(default=0, description="The index of the interaction in the chat example that was last processed")
+    is_training_example: bool = Field(description="Whether the test case is a training example")
+    knowleadge_base: List[KnowleadgeBaseComponent] = Field(default_factory=list, description="The knowleadge base of the test case", alias="knowledge_base")
 
     @classmethod
     def from_chat_example(cls, chat_example: ChatExample, ai_agent_id: StrObjectId) -> List[ChatExampleTestCase]:
@@ -56,7 +60,7 @@ class ChatExampleTestCase(AiAgentComponent):
         return cls(
             chat_example_id=chat_example.id,
             ai_agent_id=ai_agent_id,
-            filter_criteria_id=[filter_criteria_id] if filter_criteria_id else [],
+            filter_criteria=[filter_criteria_id] if filter_criteria_id else [],
             status=ChatExampleTestCaseStatus.PENDING,
             start_time=None,
             end_time=None,
@@ -64,5 +68,10 @@ class ChatExampleTestCase(AiAgentComponent):
             name=chat_example.name,
             updated_at=datetime.now(ZoneInfo("UTC")),
             created_at=datetime.now(ZoneInfo("UTC")),
-            type=AiAgentComponentType.TEST_CASE
+            type=AiAgentComponentType.TEST_CASE,
+            is_training_example=chat_example.is_training_example
         )
+
+    @property
+    def filter_criteria_id(self) -> Optional[StrObjectId]:
+        return self.filter_criteria[0] if self.filter_criteria else None
\ No newline at end of file
