@@ -17,8 +17,9 @@ class ChattyFastAnswer(CompanyAssetModel):
     }
 
     model_config = ConfigDict(
-        populate_by_name=True
-    )
+        validate_by_name=True,
+        validate_by_alias=True
+                )
 
     @model_validator(mode='after')
     def set_context_and_subtype_on_messages(self):
