@@ -11,10 +11,10 @@ logger = logging.getLogger("logger")
 class FlowPreview(CompanyAssetModel):
     """This class is only used to preview the workflow. It is not used to create or update the flow."""
     title: str
-    description: str
     created_at: datetime = Field(default_factory=lambda: datetime.now(tz=ZoneInfo("UTC")))
     updated_at: datetime = Field(default_factory=lambda: datetime.now(tz=ZoneInfo("UTC")))
     company_id: StrObjectId = Field(alias="companyId")
+    visible: bool = Field(default=True)
 
     @property
     def is_smart_follow_up(self) -> bool:
