@@ -1,7 +1,11 @@
+from letschatty.models.utils.types.identifier import StrObjectId
 from ...base_models.chatty_asset_model import CompanyAssetModel, ChattyAssetPreview
 from typing import Dict, Any, Optional, ClassVar
-from pydantic import Field, field_validator
+from pydantic import Field, field_validator, BaseModel
 import pycountry
+from datetime import datetime
+from zoneinfo import ZoneInfo
+import json
 
 class ProductPreview(ChattyAssetPreview):
     color: str = Field(default="#000000")
@@ -25,7 +29,6 @@ class ProductPreview(ChattyAssetPreview):
 class Product(CompanyAssetModel):
     name: str
     price: Optional[Dict[str, float]] = Field(default=None)
-    information: Optional[str] = Field(default=None)
     parameters: Optional[Dict[str, Any]] = Field(default=None)
     external_id: Optional[str] = Field(default=None)
     preview_class: ClassVar[type[ProductPreview]] = ProductPreview
@@ -35,6 +38,13 @@ class Product(CompanyAssetModel):
     def validate_price(cls, v: Dict[str, float]):
         if v is None:
             return v
+        if isinstance(v, str):
+            try:
+                v = json.loads(v)
+            except json.JSONDecodeError:
+                # Handle Python dict string format (single quotes)
+                import ast
+                v = ast.literal_eval(v)
         for currency, amount in v.items():
             try:
                 pycountry.currencies.get(alpha_3=currency)
@@ -45,3 +55,13 @@ class Product(CompanyAssetModel):
 
         return v
 
+class ProductToDelete(BaseModel):
+    id: Optional[StrObjectId] = Field(default=None)
+    company_id: StrObjectId
+    external_id: Optional[str] = Field(default=None)
+    deleted_at: datetime = Field(default_factory=lambda: datetime.now(ZoneInfo("UTC")))
+
+    class ConfigDict:
+        arbitrary_types_allowed = True
+
+
