@@ -90,6 +90,10 @@ class ChattyAssetCollectionInterface(Generic[T, P], ABC):
         logger.debug(f"Found {len(docs)} preview documents in collection {self.collection.name}")
         return [self.preview_type.from_dict(doc) for doc in docs]
 
+    def get_projection_by_query(self, query = {}, projection = {}) -> List[Dict[str, Any]]:
+        docs = self.collection.find(query, projection=projection)
+        return [doc for doc in docs]
+
     def get_by_query(self, query = {}) -> List[T]:
         docs = self.collection.find(query)
         return [self.create_instance(doc) for doc in docs]
