@@ -3,4 +3,7 @@ from pydantic import BaseModel, Field
 class ChattyContentSticker(BaseModel):
     url: str = Field(description="URL of the media from S3")
     mime_type: str
-    sha256: str
\ No newline at end of file
+    sha256: str
+
+    def get_body_or_caption(self) -> str:
+        return f"Sticker: {self.url}"
\ No newline at end of file
