@@ -8,8 +8,8 @@ if TYPE_CHECKING:
 
 class ChattyReferral(BaseModel):
     source_url: str
-    source_id: str
-    source_type: str
+    source_id: Optional[str] = None
+    source_type: Optional[str] = None
     headline: Optional[str] = None
     body: Optional[str] = None
     media_type: Optional[str] = None
@@ -26,6 +26,7 @@ class ChattyReferral(BaseModel):
     def from_meta(cls, meta_referral: MetaReferral | None) -> ChattyReferral:
         if meta_referral is None:
             return cls.default()
+        meta_referral.source_url = meta_referral.source_url.strip() # remove trailing spaces
         return cls(**meta_referral.model_dump())
 
     @classmethod
