@@ -3,6 +3,7 @@ from letschatty.models.company.assets.ai_agents_v2.follow_up_strategy import Fol
 from letschatty.models.company.assets.ai_agents_v2.context_item import ContextItem
 from letschatty.models.company.assets.ai_agents_v2.chat_example import ChatExample
 from letschatty.models.base_models.ai_agent_component import AiAgentComponent
+from letschatty.models.company.assets.ai_agents_v2.knowleadge_base_components import KnowleadgeBaseComponent
 from letschatty.models.company.assets.filter_criteria import FilterCriteria
 
 from letschatty.models.company.assets.ai_agents_v2.faq import FAQ
@@ -65,3 +66,11 @@ class AiComponentsService:
         except ValueError:
             logger.debug(f"Filter criteria {filter_criteria_id} not found in component {component.name} ({component.id}) - returning 200")
             raise AlreadyCompleted(f"Filter criteria {filter_criteria_id} not found in component {component.id}")
+
+    @staticmethod
+    def ai_component_to_knowleadge_base_component(component: AiAgentComponent) -> KnowleadgeBaseComponent:
+        return KnowleadgeBaseComponent(
+            name=component.name,
+            type=component.type,
+            id=component.id
+        )
\ No newline at end of file
