@@ -14,10 +14,13 @@ from letschatty.models.chat.highlight import Highlight, HighlightRequestData
 from letschatty.models.chat.quality_scoring import QualityScore
 from letschatty.models.copilot.links import LinkItem
 from letschatty.models.chat.flow_link_state import FlowStateAssignedToChat
+from letschatty.models.company.conversation_topic import TopicTimelineEntry
+from letschatty.models.company.form_field import CollectedData
 from datetime import datetime
 from typing import Dict, Any, Optional, List, TYPE_CHECKING
 from letschatty.models.execution.execution import ExecutionContext
 from letschatty.models.messages.meta_message_model.meta_status_json import ErrorDetail
+from letschatty.services.continuous_conversation_service.continuous_conversation_helper import ContinuousConversationHelper
 from ...models.company.assets.product import Product
 from ...models.company.assets.ai_agents_v2.chatty_ai_agent import ChattyAIAgent
 from ...models.company.assets.ai_agents_v2.chatty_ai_mode import ChattyAIMode
@@ -30,6 +33,7 @@ from ...models.messages.chatty_messages.base.message_draft import ChattyContentA
 from ...models.messages.chatty_messages.schema.chatty_content.content_central import CentralNotificationStatus
 from ...models.messages.chatty_messages.schema import ChattyContext
 from ...models.utils.types.message_types import MessageType
+from .conversation_topics_service import ConversationTopicsService
 import logging
 import bisect
 from ...models.analytics.events.chat_based_events.chat_context import ChatContext
@@ -112,7 +116,7 @@ class ChatService:
         )
         execution_context.set_event_time(assigned_asset.assigned_at)
         bisect.insort(chat.client.products, assigned_asset)
-        ChatService.add_central_notification_from_text(chat=chat, body=f"Producto {product.name} agregado al chat {chat.id} por {execution_context.executor.name}", subtype=MessageSubtype.PRODUCT_ADDED)
+        ChatService.add_central_notification_from_text(chat=chat, body=f"Producto {product.name} agregado al chat {chat.id} por {execution_context.executor.name}", subtype=MessageSubtype.PRODUCT_ADDED, context=ChattyContext(chain_of_thought_id=execution_context.chain_of_thought_id))
         return assigned_asset
 
     @staticmethod
@@ -144,7 +148,7 @@ class ChatService:
         )
         execution_context.set_event_time(assigned_asset.assigned_at)
         bisect.insort(chat.client.tags, assigned_asset)
-        ChatService.add_central_notification_from_text(chat=chat, body=f"Etiqueta {tag.name} agregada al chat {chat.id} por {execution_context.executor.name}", subtype=MessageSubtype.TAG_ADDED)
+        ChatService.add_central_notification_from_text(chat=chat, body=f"Etiqueta {tag.name} agregada al chat {chat.id} por {execution_context.executor.name}", subtype=MessageSubtype.TAG_ADDED, context=ChattyContext(chain_of_thought_id=execution_context.chain_of_thought_id))
         logger.debug(f"added tag {tag} to chat {chat.id}")
         return assigned_asset
 
@@ -429,7 +433,12 @@ class ChatService:
         message.update_status(new_status=status, status_datetime=datetime.now())
         if message.subtype == MessageSubtype.TEMPLATE and status == Status.FAILED and error_details is not None:
             ChatService.add_central_notification_from_text(chat=chat, body=f"La plantilla de mensaje {message.context.template_name} falló: {error_details.get_error_details()}", subtype=MessageSubtype.META_ERROR, content_status=CentralNotificationStatus.ERROR)
-
+            if message.is_cc_related:
+                active_cc = ContinuousConversationHelper.get_active_cc(chat=chat)
+                if active_cc:
+                    active_cc = ContinuousConversationHelper.handle_failed_template_cc(chat=chat, cc=active_cc, error_details=error_details.get_error_details())
+                else:
+                    logger.warning(f"No active CC found for chat {chat.id}")
             logger.warning(f"Template {message.context.template_name} failed: {error_details.get_error_details()}")
             raise MetaErrorNotification(message=f"Template {message.context.template_name} failed", status_code=400, chat_id=chat.identifier, details=error_details.get_more_info())
         return message
@@ -637,6 +646,7 @@ class ChatService:
         chat.client.lead_quality = quality_score
         logger.debug(f"Chat {chat.id} qualified as {quality_score.value}")
         execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
+        ChatService.add_central_notification_from_text(chat=chat, body=f"El chat fue calificado como {quality_score.value} por {execution_context.executor.name}", subtype=MessageSubtype.CLIENT_INFO_UPDATED, context=ChattyContext(chain_of_thought_id=execution_context.chain_of_thought_id))
         return chat
 
     @staticmethod
@@ -651,6 +661,8 @@ class ChatService:
             chat.client.DNI = client_data.DNI
         if client_data.external_id is not None:
             chat.client.external_id = client_data.external_id
+        if client_data.lead_form_data is not None:
+            chat.client.lead_form_data = client_data.lead_form_data
         execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
         ChatService.add_central_notification_from_text(chat=chat, body=f"La info del cliente fue actualizada por {execution_context.executor.name}", subtype=MessageSubtype.CLIENT_INFO_UPDATED)
         return chat
@@ -721,4 +733,140 @@ class ChatService:
         message.content.transcription = transcript
         logger.debug(f"Added audio transcription to chat {chat.id} #{chat.client.get_waid()}")
         execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
-        return chat
\ No newline at end of file
+        return chat
+
+    # ============================================================================
+    # Conversation Topics Methods
+    # ============================================================================
+
+    @staticmethod
+    def update_conversation_topics(
+        chat: Chat,
+        detected_topics: List[str],
+        execution_context: ExecutionContext
+    ) -> TopicTimelineEntry:
+        """
+        Update conversation topics based on tagger agent output.
+
+        Simply adds new timeline entry with detected topics.
+        Topics replace previous active topics.
+
+        Args:
+            chat: Chat instance
+            detected_topics: List of topic names detected by tagger
+            execution_context: Execution context for event tracking
+
+        Returns:
+            The new timeline entry that was added
+        """
+        entry = ConversationTopicsService.update_topics(
+            chat=chat,
+            detected_topics=detected_topics
+        )
+
+        execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
+
+        # Log update
+        logger.info(f"Updated topics for chat {chat.id}: {detected_topics}")
+
+        return entry
+
+    @staticmethod
+    def get_active_conversation_topics(chat: Chat) -> List[str]:
+        """
+        Get currently active conversation topics.
+
+        Args:
+            chat: Chat instance
+
+        Returns:
+            List of active topic names
+        """
+        return chat.active_topics
+
+    @staticmethod
+    def cancel_all_conversation_topics(
+        chat: Chat,
+        execution_context: ExecutionContext
+    ) -> TopicTimelineEntry:
+        """
+        Manually cancel all active conversation topics.
+
+        Adds empty timeline entry to mark cancellation.
+
+        Args:
+            chat: Chat instance
+            execution_context: Execution context for event tracking
+
+        Returns:
+            The empty timeline entry that was added
+        """
+        entry = ConversationTopicsService.cancel_all_topics(chat)
+
+        execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
+        ChatService.add_central_notification_from_text(
+            chat=chat,
+            body=f"All conversation topics cleared by {execution_context.executor.name}",
+            subtype=MessageSubtype.SYSTEM
+        )
+
+        return entry
+
+    # ============================================================================
+    # Data Collection Methods
+    # ============================================================================
+
+    @staticmethod
+    def update_collected_data(
+        chat: Chat,
+        collected_data: CollectedData,
+        execution_context: ExecutionContext
+    ) -> CollectedData:
+        """
+        Update collected customer data in the chat.
+
+        Args:
+            chat: Chat instance
+            collected_data: New collected data from tagger
+            execution_context: Execution context for event tracking
+
+        Returns:
+            Updated CollectedData object
+        """
+
+        # Update fields that have new values
+        updated_fields = []
+
+        if collected_data.name and chat.client.name != collected_data.name:
+            chat.client.name = collected_data.name
+            updated_fields.append("name")
+
+        if collected_data.email and chat.client.email != collected_data.email:
+            chat.client.email = collected_data.email
+            updated_fields.append("email")
+
+        if collected_data.document_id and chat.client.document_id != collected_data.document_id:
+            chat.client.document_id = collected_data.document_id
+            updated_fields.append("document_id")
+
+
+        # Merge additional_fields
+        if collected_data.additional_fields:
+
+            for key, value in collected_data.additional_fields.items():
+                if value is not None and chat.client.lead_form_data.get(key) != value:
+                    chat.client.lead_form_data[key] = value
+                    updated_fields.append(key)
+
+        if updated_fields:
+            execution_context.set_event_time(datetime.now(tz=ZoneInfo("UTC")))
+            logger.info(f"Updated collected data for chat {chat.id}: {', '.join(updated_fields)}")
+
+            ChatService.add_central_notification_from_text(
+                chat=chat,
+                body=f"Collected customer data: {', '.join(updated_fields)}",
+                subtype=MessageSubtype.CLIENT_INFO_UPDATED,
+                context=ChattyContext(chain_of_thought_id=execution_context.chain_of_thought_id)
+            )
+
+        return chat.client.lead_form_data
\ No newline at end of file
