@@ -176,6 +176,8 @@ class ChattyAssetContainerWithCollection(ChattyAssetBaseContainer[T, P], ABC):
             logger.debug(f"{self.__class__.__name__} getting item {id} not found in container, trying to get from collection")
             item = self.collection.get_by_id(id)
             if item:
+                if item.deleted_at is not None:
+                    return item
                 self.item_last_accessed_at_cache[id] = datetime.now(ZoneInfo("UTC"))
                 return self.add_to_memory(item)
             else:
@@ -194,7 +196,7 @@ class ChattyAssetContainerWithCollection(ChattyAssetBaseContainer[T, P], ABC):
 
     def get_all_previews(self, company_id: Optional[StrObjectId]) -> List[Dict[str, Any]]:
         """We get the previews for one company and update the last_accessed_at cache"""
-        logger.info(f"Getting all previews for {self.__class__.__name__}")
+        logger.debug(f"Getting all previews for {self.__class__.__name__}")
         if not self.cache_config.keep_previews_always_in_memory and (self.preview_last_accessed_at_cache < datetime.now(ZoneInfo("UTC")) - timedelta(seconds=self.cache_config.cache_expiration_time_previews) or not self.preview_items):
             logger.debug(f"Clearing previews cache of {self.__class__.__name__}")
             self.update_previews_cache()
@@ -225,8 +227,11 @@ class ChattyAssetContainerWithCollection(ChattyAssetBaseContainer[T, P], ABC):
                 ids_to_remove.append(id)
         logger.debug(f"Clearing cache of {len(ids_to_remove)} {self.item_type.__name__}")
         for id in ids_to_remove:
-            del self.items[id]
-            del self.item_last_accessed_at_cache[id]
+            # Safe deletion: only delete if the item exists in both dictionaries
+            if id in self.items:
+                del self.items[id]
+            if id in self.item_last_accessed_at_cache:
+                del self.item_last_accessed_at_cache[id]
 
     def clear_previews_cache(self):
         """Clear the cache of all previews that have not been accessed in the cache_expiration_time_previews"""
